/*
 * Project_name:
     Bipolar Stepper Motor Driver Board
 * Copyright:
     (c) Mikroelektronika, 2010.
 * Revision History
     20101102:
    - Initial release;
    - 20101102(RR);
 * Description:
     This is code that contorls Bipolar Motor with arrow keypad and show current state on LCD. It can however work witout one too.
 * Test configuration:
    mcu:                 ac:dsPIC30F4013
                         http://ww1.microchip.com/downloads/en/devicedoc/70138c.pdf

    Dev.Board:           ac:EasydsPIC6
                         http://www.mikroe.com/eng/products/view/434/easydspic6-development-system/

    Oscillator:          XT, 10.0000 MHz with 8x PLL

     Ext. Modules:       ac:Bipolar_Stepper_Motor_Driver_Board
                         http://www.mikroe.com/eng/products/view/217/bipolar-stepper-motor-driver-board/

     SW:                 mikroC PRO for dsPIC v4.10
                         http://www.mikroe.com/en/compilers/mikroc/pro/dspic/

 * NOTES:
  - For regular functionality MCU must work on 8.0000 MHz oscillator.
  - Connect LCD, but it's not needed
  - Bipolar Stepper Motor Driver Board must be connected on Port1
  - Turn On LCD backlight switch (SW11.8) and and Pull Up jumper (J15) and Port switches (SW2.6, SW2.7 and SW3.8)
  - Use Button RA11 for phase shift and RC13, RC14 for rotation direction
*/


// LCD module connections
sbit LCD_RS at LATD0_bit;
sbit LCD_EN at LATD1_bit;
sbit LCD_D4 at LATB0_bit;
sbit LCD_D5 at LATB1_bit;
sbit LCD_D6 at LATB2_bit;
sbit LCD_D7 at LATB3_bit;

sbit LCD_RS_Direction at TRISD0_bit;
sbit LCD_EN_Direction at TRISD1_bit;
sbit LCD_D4_Direction at TRISB0_bit;
sbit LCD_D5_Direction at TRISB1_bit;
sbit LCD_D6_Direction at TRISB2_bit;
sbit LCD_D7_Direction at TRISB3_bit;
// End LCD module connections

  char t = 0;
  char k = 200;
  int no;
  int tmp;

void main() {                          // Main Program

  ADPCFG = 0xFFFF;                     // Set AN pins as Digital I/O

  TRISA = 0xFFFF;                      // Set PortA as input
  PORTA = 0;

  TRISC = 0xFFFF;                      // Set PortC as input
  PORTC = 0;

  TRISF = 0x0000;                      // Set PortB as output
  PORTF = 0xFFFF;


  Lcd_Init();                          // Initialize LCD

  Lcd_Cmd(_LCD_CLEAR);                 // Clear display
  Lcd_Cmd(_LCD_CURSOR_OFF);            // Cursor off

  Lcd_Out(1, 1, "Speed: ");
  Lcd_Out(1, 9, "1");
  Lcd_Out(2, 1, "Rotation: ");

  no = 0;                              // temporary variables
  tmp = 0x00;

  while (1) {
    Delay_ms(10);

    // sellecting step
    if (PORTA.B11) {                   // if key is pressed
      Delay_ms(100);
      if (PORTA.B11) {                 // longer then 100ms make smaller step
        switch (no) {
          case 0:
            Lcd_Out(1, 9, "1  ");
            tmp = 0b00000000;
            break;
          case 1:
            Lcd_Out(1, 9, "1/2");
            tmp = 0b00001000;
            break;
          case 2:
            Lcd_Out(1, 9, "1/4");
            tmp = 0b00010000;
            break;
          case 3:
            Lcd_Out(1, 9, "1/8");
            tmp = 0b00011000;
            break;
        }
        no++;
        if (no > 3)
          no = 0;
      }
    }

    // move motor to left - CCW
    if (PORTC.B14) {
      Lcd_Out(2, 11, "left ");
      PORTF = 0b10000000 + tmp;
      for (t=0; t<=k; t++) {
        PORTF = 0b10000110 + tmp;
        Delay_ms(5);
        PORTF = 0b10000100 + tmp;
        Delay_ms(5);
      }
      Delay_ms(300);
      Lcd_Out(2, 11, "     ");
      PORTF = 0b10000101 + tmp;
      while (PORTC.B14) ;
    }

    // move motor to right - CW
    if (PORTC.B13) {
      Lcd_Out(2, 11, "right");
      PORTF = 0b11000000 + tmp;
      for (t=0; t<=k; t++) {
        PORTF = 0b11000110 + tmp;
        Delay_ms(5);
        PORTF = 0b11000100 + tmp;
        Delay_ms(5);
      }
      Delay_ms(300);
      Lcd_Out(2, 11, "     ");
      PORTF = 0b11000101 + tmp;
      while (PORTC.B13) ;
    }
  }
}